@@ -291,21 +291,19 @@ def query_redshift(query, dsn_dict=None, jdbc_driver_loc=None):
     '''
 
     if dsn_dict is None:
-        acct = settings.redshift_svc_acct
-        dsn_database= acct.dsn_database
-        dsn_hostname= acct.dsn_hostname
-        dsn_port= acct.dsn_port
-        dsn_uid= acct.dsn_uid
-        dsn_pwd= acct.dsn_pwd
+        acct = settings.REDSHIFT_SVC_ACCT
+        dsn_database= acct['dsn_database']
+        dsn_hostname= acct['dsn_hostname']
+        dsn_port= acct['dsn_port']
+        dsn_uid= acct['dsn_uid']
+        dsn_pwd= acct['dsn_pwd']
     
     if jdbc_driver_loc is None:
         jdbc_driver_loc = settings.redshift_driver_path
 
-    jdbc_driver_name = "com.amazon.redshfit.jdbc42.Driver"
+    jdbc_driver_name = "com.amazon.redshift.jdbc42.Driver"
 
-    sql_str = query
-
-    connection_string = 'jdbc:redshift://' + dsn_hostname + ':' + dsn_port + '/' + dsn_database
+    connection_string = 'jdbc:redshift://' + dsn_hostname + ':' + str(dsn_port) + '/' + dsn_database
 
     conn = jay.connect(jdbc_driver_name, connection_string, {'user':dsn_uid, 'password': dsn_pwd}, jdbc_driver_loc)
 
